#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ABS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ABS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/abs.hpp>

#endif
